.First.lib <- function(lib, pkg) {
	library.dynam("RArcInfo", pkg, lib)
}
